# pybFoam

python bindings for OpenFOAM

currently in the pre-alpha release state


## Installation

requires OpenFOAM of2012 or higher sourced and installed and python 3.7+ (conda is highly recommended) 

```
pip install .
```


## Documentation

The documentation is found [here](https://henningscheufler.github.io/pybFoam/index.html)
